ELoginUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init({required String appId})
→ void
-
初始化,在隐私授权同意后调用即可,具体调用时机可自定义。
appId app id
-
isLoginValid()
→ Future<bool>
-
是否有效登录
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
oneKeyLogin({String? slogan, String? subSlogan, String? themeBgUrl, String? closeIconUrl, String? loginButtonText, String? loginButtonTextColor, String? loginButtonBackground, String? otherLoginButtonText, String? otherLoginButtonTextColor, String? otherLoginButtonBackground, String? protocol, String? protocolUrl, String? privacy, String? privacyUrl, OneKeyLoginCall? loginCall, dynamic startCall()?, dynamic complete()?})
→ void
-
一键登录
slogan 登录页标语
subSlogan 登录页副标语
themeBgUrl 主题背景url
closeIconUrl 关闭图标url
loginButtonText 登录按钮文本
loginButtonTextColor 登录按钮文本颜色
loginButtonBackground 登录按钮背景,仅ios
otherLoginButtonText 其它登录按钮文本
otherLoginButtonTextColor 其它登录按钮文本颜色
otherLoginButtonBackground 其它登录按钮背景,仅ios
loginCall 登录回调
startCall 开始登录
complete 完成登录
-
preLogin()
→ Future<EloginRespInfo>
-
预登录,初始化后先调用一次预登录
-
toString()
→ String
-
A string representation of this object.
inherited